<?php

/**
 * @link              https://subiz.com.vn
 * @package           Subiz
 *
 * @wordpress-plugin
 * Plugin Name:       Subiz
 * Plugin URI:        http://subiz.com.vn/wordpress-plugin
 * Description:       Subiz live chat plugin offers an excellent customer interaction platform where sales and customer service team can communicate directly with visitors, fulfil any enquiry in real-time, and actively receive feedback
 * Version:           4.2
 * Author:            Subiz
 * Author URI:        https://subiz.com.vn
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
    die;
}

define('PLUGIN_NAME_VERSION', '4.2');


class SubizPlugin
{
    public function __construct()
    {
        add_action('admin_menu', array( $this, 'admin_menu' ));
        add_action('admin_init', array( $this, 'admin_setting_form_init' ));
    }

    public static function activate()
    {
        $settings = array(
            'subiz_account_id' => '',
            'subiz_account_name' => '',
        );
        add_option('subiz_settings', $settings, '', 'yes');
    }

    public static function deactivate()
    {
        delete_option('subiz_settings');
    }

    /**
     * Registers a new settings page under Settings.
     */
    public function admin_menu()
    {
        add_menu_page(
            __('Subiz Settings', 'textdomain'),
            __('Subiz', 'textdomain'),
            'administrator',
            'subiz-plugin',
            array(
                $this,
                'settings_page'
      ),
            plugin_dir_url(dirname(__FILE__)) . 'subiz-live-chat/images/subiz_channel.svg',
        );
    }

    public function admin_setting_form_init()
    {
        register_setting('subiz_options', 'subiz_settings');
    }

    /**
     * Settings page display callback.
     */
    public function settings_page()
    {
        include sprintf('%s/page.php', dirname(__FILE__));
    }

    public function print_embed_code()
    {
        include sprintf('%s/widget.php', dirname(__FILE__));
    }
}

if (class_exists('SubizPlugin')) {
    register_activation_hook(__FILE__, array('SubizPlugin', 'activate'));
    register_deactivation_hook(__FILE__, array('SubizPlugin', 'deactivate'));

    $subiz = new SubizPlugin();
    add_action('wp_footer', array($subiz, 'print_embed_code'));
}
